#! /usr/bin/env python
# -*- coding: utf8 -*-

from django.contrib.auth.models import User
from django.core.urlresolvers import reverse
import django.test
from django.conf import settings

from freshdesk import views


class ViewsTestCase(django.test.TestCase):

    def test_user_not_logged_in(self):
        """Test with user not logged in"""
        response = self.client.get(reverse(views.authenticate))
        self.assertEqual(302, response.status_code)
        self.assertEqual(
            response['Location'], r'http://testserver%s?next=/freshdesk/' % settings.LOGIN_URL)

    def test_user_logged_in(self):
        """Test with user logged in"""

        User.objects.create_user('miafey', 'mia.fey@example.com', password='changeme',
                                 first_name='Mia', last_name='Fey')

        self.client.login(username='miafey', password='changeme')
        response = self.client.get(reverse(views.authenticate), follow=False)
        expected_url = 'http://example.com/login/sso?name=Mia%20Fey&email=mia.fey%40example.com'
        self.assertEqual(response.status_code, 302)
        self.assertTrue(expected_url in response.get('Location'))

    def testAnonymous(self):
        """Test a user with no first and last name"""

        User.objects.create_user('phoenixwright', 'phoenix.wright@example.com',
                                 password='changeme')

        self.client.login(username='phoenixwright', password='changeme')
        response = self.client.get(reverse(views.authenticate), follow=False)
        expected_url = 'http://example.com/login/sso?name=phoenixwright&email=phoenix.wright%40example.com'
        self.assertEqual(response.status_code, 302)
        self.assertTrue(expected_url in response.get('Location'))



from django.http import HttpResponseRedirect, Http404
from django.contrib.auth.decorators import login_required
from django.views.decorators.cache import never_cache
from django.conf import settings
from django.utils.encoding import iri_to_uri
from django.utils.http import urlquote
from django.core.exceptions import ImproperlyConfigured

import hashlib
import hmac
import time


@never_cache
@login_required
def authenticate(request):
    if not hasattr(settings, 'FRESHDESK_URL'):
        raise ImproperlyConfigured("Set the FRESHDESK_URL settings variable")
    if not hasattr(settings, 'FRESHDESK_SECRET_KEY'):
        raise ImproperlyConfigured("Set the FRESHDESK_SECRET_KEY settings variable")

    if not request.user:
        raise Http404()

    first_name = request.user.first_name
    last_name = request.user.last_name
    username = request.user.get_username()
    full_name = '{0} {1}'.format(first_name, last_name) if first_name or last_name else username

    utctime = int(time.time())
    data = '{0}{1}{2}'.format(
        full_name, request.user.email, utctime)
    generated_hash = hmac.new(
        settings.FRESHDESK_SECRET_KEY.encode(), data.encode(), hashlib.md5).hexdigest()
    url = '{0}login/sso?name={1}&email={2}&timestamp={3}&hash={4}'.format(settings.FRESHDESK_URL,
        urlquote(full_name), urlquote(request.user.email), utctime, generated_hash)
    return HttpResponseRedirect(iri_to_uri(url))



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
from setuptools import setup, find_packages
import freshdesk

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    os.system('python setup.py bdist_wheel upload')
    print('git tag -a %s -m "version %s"' % (freshdesk.__version__, freshdesk.__version__))
    print('git push --tags')
    sys.exit()

readme = open('README.rst').read()
changelog = open('CHANGELOG.rst').read().replace('.. :changelog:', '')

setup(
    author='That Green Space Pte Ltd',
    author_email='engineering@thatgreenspace.com.sg',
    name='django-freshdesk',
    version=freshdesk.__version__,
    description='Single Sign-On functionallity between Django and Freshdesk',
    long_description=readme + '\n' + changelog,
    url='https://github.com/ThatGreenSpace/django-freshdesk/',
    license='BSD',
    platforms=['OS Independent'],
    packages=find_packages(),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Framework :: Django',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    install_requires=[
        'Django>1.5,<1.9',
    ],
    include_package_data=True,
    zip_safe=False,
    test_suite='runtests'
)
